==> haskell-yesod-persistent-1.6.0.4-113-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yesod-persistent
version:              1.6.0.4
visibility:           public
id:                   yesod-persistent-1.6.0.4-4dCbE5AJIdCHTtlScMCrw6
key:                  yesod-persistent-1.6.0.4-4dCbE5AJIdCHTtlScMCrw6
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>

category:             Web, Yesod, Database
abi:                  55bdc5fe419a2b945025b5dd2ff81e9c
exposed:              True
exposed-modules:      Yesod.Persist Yesod.Persist.Core
import-dirs:          /usr/lib/ghc-8.10.1/site-local/yesod-persistent-1.6.0.4
library-dirs:         /usr/lib/ghc-8.10.1/site-local/yesod-persistent-1.6.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/yesod-persistent-1.6.0.4
hs-libraries:         HSyesod-persistent-1.6.0.4-4dCbE5AJIdCHTtlScMCrw6
depends:
    base-4.14.0.0 blaze-builder-0.4.1.0-2R9yQhqQRKlArR2rpVisZG
    conduit-1.3.2-AVYzW96qATz2uFqiBrAM8s
    persistent-2.10.5.2-3Qx744ImcugFLthZdJQGvw
    persistent-template-2.8.2.3-EadHihXloluIBt51jyCFlX
    resource-pool-0.2.3.2-IE3iWayGWH55HCDHOE4RID
    resourcet-1.2.4-EMqIuCF4xvx6xcJ0OcLkuC transformers-0.5.6.2
    yesod-core-1.6.18-B2icsdbJfgFLCbWTKz066C

haddock-interfaces:
    /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock

haddock-html:         /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-persistent-1.6.0.4-127-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yesod-persistent
version:              1.6.0.4
visibility:           public
id:                   yesod-persistent-1.6.0.4-8KjN7YFS1YM3JjVZTPgu9U
key:                  yesod-persistent-1.6.0.4-8KjN7YFS1YM3JjVZTPgu9U
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>

category:             Web, Yesod, Database
abi:                  471f90441ff37b93b9e2ade32b6dbbd7
exposed:              True
exposed-modules:      Yesod.Persist Yesod.Persist.Core
import-dirs:          /usr/lib/ghc-8.10.1/site-local/yesod-persistent-1.6.0.4
library-dirs:         /usr/lib/ghc-8.10.1/site-local/yesod-persistent-1.6.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/yesod-persistent-1.6.0.4
hs-libraries:         HSyesod-persistent-1.6.0.4-8KjN7YFS1YM3JjVZTPgu9U
depends:
    base-4.14.0.0 blaze-builder-0.4.1.0-2R9yQhqQRKlArR2rpVisZG
    conduit-1.3.2-HMrVpwE3Sq06WgUfKqbr9n
    persistent-2.10.5.2-Er1CUALjzK55xC2SwMj8xK
    persistent-template-2.8.2.3-GtVQLOud6BjKjBSWKNaJ7o
    resource-pool-0.2.3.2-AL1yxJa918z1rJuEdv84MN
    resourcet-1.2.4-D9lelWYYOwO39oUPVIVnqn transformers-0.5.6.2
    yesod-core-1.6.18-96OxT1VNNB7Lu6JO6UOTXE

haddock-interfaces:
    /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock

haddock-html:         /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
